@@ -166,6 +166,26 @@ describe Puppet::Resource::Catalog::Puppetdb do
         resource['parameters']['alias'].should be_nil
       end
 
+      describe "for resources with composite namevars" do
+        let(:resource) do
+          r = Puppet::Resource.new(:notify, 'yo matey')
+          r.stubs(:key_attributes).returns [:name, :message]
+          r
+        end
+
+        it "should not create aliases" do
+          hash = subject.add_parameters_if_missing(catalog_data_hash)
+          result = subject.add_namevar_aliases(hash, catalog)
+
+          resource = result['resources'].find do |res|
+            res['type'] == 'Notify' and res['title'] == 'yo matey'
+          end
+
+          resource.should_not be_nil
+          resource['parameters']['alias'].should be_nil
+        end
+      end
+
       describe "for non-isomorphic resources" do
         let(:resource) do
           Puppet::Resource.new(:exec, 'an_exec', :parameters => {:command => '/bin/true'})
