@@ -61,8 +61,8 @@
   "Send the given wire-format catalog (associated with `host`) to a
   command-processing endpoint."
   [host catalog]
-  (let [result (command/submit-command hostname port catalog "replace catalog" 1)]
-    (if (not= 200 (:status result))
+  (let [result (command/submit-command-via-http! hostname port "replace catalog" 1 catalog)]
+    (if (not= pl-http/status-ok (:status result))
       (log/error result))))
 
 (defn tweak-catalog
