@@ -1,6 +1,6 @@
 (ns com.puppetlabs.puppetdb.http.catalog
   (:require [cheshire.core :as json]
-            [com.puppetlabs.utils :as utils]
+            [com.puppetlabs.http :as pl-http]
             [com.puppetlabs.puppetdb.query.catalog :as c]
             [ring.util.response :as rr])
   (:use [com.puppetlabs.jdbc :only (with-transacted-connection)]))
@@ -11,8 +11,8 @@
   (let [catalog (with-transacted-connection db
                   (c/catalog-for-node node))]
     (if catalog
-      (utils/json-response catalog)
-      (utils/json-response {:error (str "Could not find catalog for " node)} 404))))
+      (pl-http/json-response catalog)
+      (pl-http/json-response {:error (str "Could not find catalog for " node)} pl-http/status-not-found))))
 
 (defn catalog-app
   "Ring app for retrieving catalogs"
@@ -21,9 +21,9 @@
     (cond
      (empty? node)
      (-> (rr/response "missing node")
-         (rr/status 400))
+         (rr/status pl-http/status-bad-request))
 
-     (not (utils/acceptable-content-type
+     (not (pl-http/acceptable-content-type
            "application/json"
            (headers "accept")))
      (-> (rr/response "must accept application/json"))
