@@ -13,7 +13,7 @@
 
 (ns com.puppetlabs.puppetdb.http.facts
   (:require [cheshire.core :as json]
-            [com.puppetlabs.utils :as utils]
+            [com.puppetlabs.http :as pl-http]
             [com.puppetlabs.puppetdb.query.facts :as f]
             [ring.util.response :as rr])
   (:use [com.puppetlabs.jdbc :only (with-transacted-connection)]))
@@ -24,8 +24,8 @@
   (let [facts (with-transacted-connection db
                 (f/facts-for-node node))]
     (if-not (seq facts)
-      (utils/json-response {:error (str "Could not find facts for " node)} 404)
-      (utils/json-response {:name node :facts facts}))))
+      (pl-http/json-response {:error (str "Could not find facts for " node)} pl-http/status-not-found)
+      (pl-http/json-response {:name node :facts facts}))))
 
 (defn facts-app
   "Ring app for querying facts"
@@ -33,13 +33,13 @@
   (cond
    (not (params "node"))
    (-> (rr/response "missing node")
-       (rr/status 400))
+       (rr/status pl-http/status-bad-request))
 
-   (not (utils/acceptable-content-type
+   (not (pl-http/acceptable-content-type
          "application/json"
          (headers "accept")))
    (-> (rr/response "must accept application/json")
-       (rr/status 406))
+       (rr/status pl-http/status-not-acceptable))
 
    :else
    (produce-body (params "node") (:scf-db globals))))
