@@ -7,20 +7,23 @@
 (ns com.puppetlabs.utils
   (:import [org.ini4j Ini]
            [org.apache.log4j PropertyConfigurator]
+           [org.apache.log4j ConsoleAppender]
+           [org.apache.log4j PatternLayout]
+           [org.apache.log4j Logger]
+           [org.apache.log4j Level]
            [javax.naming.ldap LdapName])
   (:require [clojure.test]
             [clojure.tools.logging :as log]
             [clojure.string :as string]
             [clojure.tools.cli :as cli]
-            [cheshire.core :as json]
             [digest]
-            [fs.core :as fs]
-            [ring.util.response :as rr])
+            [fs.core :as fs])
   (:use [clojure.core.incubator :only (-?> -?>>)]
         [clojure.java.io :only (reader)]
         [clojure.set :only (difference union)]
         [clojure.stacktrace :only (print-cause-trace)]
         [clj-time.core :only [now]]
+        [clj-time.coerce :only [ICoerce]]
         [clj-time.format :only [formatters unparse]]
         [slingshot.slingshot :only (try+ throw+)]))
 
@@ -128,7 +131,13 @@
    :post [(set? %)]}
   (set (vals m)))
 
-;; ## Timestamping
+;; ## Date and Time
+
+(defn datetime?
+  "Predicate returning whether or not the supplied object is
+  convertible to a Joda DateTime"
+  [x]
+  (satisfies? ICoerce x))
 
 (defn timestamp
   "Returns a timestamp string for the given `time`, or the current time if none
@@ -286,6 +295,41 @@
   {:pre [(fn? f)]}
   (.addShutdownHook (Runtime/getRuntime) (Thread. f)))
 
+(defn create-console-appender
+  "Instantiates and returns a logging appender configured to write to
+  the console, using the standard puppetdb logging configuration.
+
+  `level` is an optional argument (of type `org.apache.log4j.Level`)
+  indicating the logging threshold for the new appender.  Defaults
+  to `DEBUG`."
+  ([]
+     (create-console-appender Level/DEBUG))
+  ([level]
+     {:pre [(instance? Level level)]}
+     (let [layout (PatternLayout. "%d %-5p [%t] [%c{2}] %m%n")]
+       (doto (ConsoleAppender.)
+         (.setLayout layout)
+         (.setThreshold level)
+         (.activateOptions)))))
+
+(defn add-console-logger!
+  "Adds a console logger to the current logging configuration, and ensures
+  that the root logger is set to log at the logging level of the new
+  logger or finer.
+
+  `level` is an optional argument (of type `org.apache.log4j.Level`)
+  indicating the logging threshold for the new logger.  Defaults
+  to `DEBUG`."
+  ([]
+     (add-console-logger! Level/DEBUG))
+  ([level]
+     {:pre [(instance? Level level)]}
+     (let [root-logger (Logger/getRootLogger)]
+       (.addAppender root-logger (create-console-appender level))
+       (if (> (.toInt (.getLevel root-logger))
+              (.toInt level))
+         (.setLevel root-logger level)))))
+
 (defn configure-logger-via-file!
   "Reconfigures the current logger based on the supplied configuration
   file. You can optionally supply a delay (in millis) that governs how
@@ -304,13 +348,32 @@
   "If there is a logging configuration directive in the supplied
   config map, use it to configure the default logger. Returns the same
   config map that was passed in."
-  [{:keys [global] :as config}]
+  [{:keys [global debug] :as config}]
   {:pre  [(map? config)]
    :post [(map? %)]}
   (when-let [logging-conf (:logging-config global)]
     (configure-logger-via-file! logging-conf))
+  (when debug
+    (add-console-logger! Level/DEBUG)
+    (log/debug "Debug logging enabled"))
   config)
 
+(defmacro demarcate
+  "Executes `body`, but logs `msg` to info before and after `body` is
+  executed. `body` is executed in an implicit do, and the last
+  expression's return value is returned by `demarcate`.
+
+    user> (demarcate \"reticulating splines\" (+ 1 2 3))
+    \"Starting reticulating splines\"
+    \"Finished reticulating splines\"
+    6
+  "
+  [msg & body]
+  `(do (log/info (str "Starting " ~msg))
+       (let [result# (do ~@body)]
+         (log/info (str "Finished " ~msg))
+         result#)))
+
 ;; ## Command-line parsing
 
 (defn cli!
@@ -323,6 +386,7 @@
   (let [specs                    (conj specs
                                        ["-c" "--config" "Path to config.ini" :required true]
                                        ["-h" "--help" "Show help" :default false :flag true]
+                                       ["-D" "--debug" "Enable debug mode" :default false :flag true]
                                        ["--trace" "Print stacktraces on error" :default false :flag true])
         [options posargs banner] (apply cli/cli args specs)]
     (when (:help options)
@@ -390,51 +454,6 @@
       (or (= scheme :http)
           (allowed? ssl-client-cn)))))
 
-(defn acceptable-content-type
-  "Returns a boolean indicating whether the `candidate` mime type
-  matches any of those listed in `header`, an Accept header."
-  [candidate header]
-  {:pre [(string? candidate)]}
-  (if-not (string? header)
-    true
-    (let [[prefix suffix] (.split candidate "/")
-          wildcard        (str prefix "/*")
-          types           (->> (clojure.string/split header #",")
-                               (map #(.trim %))
-                               (set))]
-      (or (types wildcard)
-          (types candidate)))))
-
-(defn json-response
-  "Returns a Ring response object with the supplied `body` and response `code`,
-  and a JSON content type. If unspecified, `code` will default to 200."
-  ([body]
-     (json-response body 200))
-  ([body code]
-     (-> body
-         (json/generate-string {:date-format "yyyy-MM-dd'T'HH:mm:ss.SSS'Z'"})
-         (rr/response)
-         (rr/header "Content-Type" "application/json")
-         (rr/status code))))
-
-(defn error-response
-  "Returns a Ring response object with a status code of 400. If `error` is a
-  Throwable, its message is used as the body of the response. Otherwise,
-  `error` itself is used."
-  [error]
-  (let [msg (if (instance? Throwable error)
-              (.getMessage error)
-              (str error))]
-    (-> msg
-        (rr/response)
-        (rr/status 400))))
-
-(defn uri-segments
-  "Converts the given URI into a seq of path segments. Empty segments
-  (from a `//`, for example) are elided from the result"
-  [uri]
-  (remove #{""} (.split uri "/")))
-
 ;; ## Hashing
 
 ;; This method lookup is surprisingly expensive (on the order of 10x slower),
